@@ -8,6 +8,7 @@ from typing import List
 
 from blulib.config_parser import ConfigParser
 from tealprint import TealPrint
+from tealprint.teallevel import TealLevel
 from youtube_series_downloader.config import General, config
 from youtube_series_downloader.core.channel import Channel
 
@@ -17,6 +18,7 @@ class ConfigGateway:
         self.path = Path.home().joinpath(f".{config.app_name}.cfg")
         self.parser = ConfigParser(interpolation=ExtendedInterpolation())
 
+    def check_config_exists(self) -> None:
         if not self.path.exists():
             TealPrint.info(f"Could not find any configuration file in {self.path}")
             user_input = input("Do you want to copy the example config and edit it (y/n)?")
@@ -46,7 +48,21 @@ class ConfigGateway:
             "int:threads",
             "float:speed_up_default",
             "int:max_days_back",
+            "log_level",
         )
+        if not general.series_dir:
+            TealPrint.warning(f"Missing 'series_dir' in [General] in your configuration. Please add it.", exit=True)
+
+        # Convert string to LogLevel
+        if isinstance(general.log_level, str):
+            try:
+                general.log_level = TealLevel[general.log_level]
+            except KeyError:
+                TealPrint.warning(
+                    f"Failed to set log_level from config, invalid level: {general.log_level}. Setting log_level to info"
+                )
+                general.log_level = TealLevel.info
+
         return general
 
     def get_channels(self) -> List[Channel]:
@@ -59,11 +75,18 @@ class ConfigGateway:
                     channel,
                     section,
                     "id",
+                    "name",
                     "dir->collection_dir",
                     "float:speed",
                     "str_list:includes",
                     "str_list:excludes",
                 )
+
+                if not channel.id:
+                    TealPrint.warning(
+                        f"Missing 'id' for channel [{section}] in your configuration. Please add it.", exit=True
+                    )
+
                 channels.append(channel)
         return channels
 
